@@ -11,7 +11,7 @@
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -29,7 +29,7 @@
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -75,7 +75,7 @@
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -152,7 +152,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -167,7 +167,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -214,7 +214,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -258,7 +258,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -272,7 +272,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -318,7 +318,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -377,7 +377,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -392,7 +392,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -438,7 +438,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -496,7 +496,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -511,7 +511,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -558,7 +558,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -764,7 +764,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -777,7 +777,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -824,7 +824,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -900,7 +900,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -914,7 +914,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following integer vectors  \code{f, h} and integers \code{NL, NI, C}.
+#'  A list consists of two integer vectors  \code{f, h} and three integers \code{NL, NI, C}.
 #'
 
 #'
@@ -960,7 +960,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -1026,7 +1026,7 @@ NULL
 #' however,  confidence level vector \code{c } should not be specified.
 #'  If specified, will be ignored ,
 #'  since it is created by \code{  c <-c(rep(C:1))} in the program
-#'  and do not refer from user input data,
+#'  and it does not refer from user input data,
 #'  where \code{C} is the highest number of confidence levels.
 #'Should write down your hits and
 #'false alarms vector so that it is compatible with this automatically created  vector \code{c}.
@@ -1040,7 +1040,7 @@ NULL
 #'
 #'
 #' @format
-#'  This data list contains the following
+#'  A list consists of the following
 #'   integer vectors  \code{f, h} and integers \code{NL, NI, C}.
 #'
 
@@ -1087,7 +1087,7 @@ NULL
 #'In the absent case, reader dose not mark any locations and hence, the absent cofidence level does not relate this dataset.
 #'
 #'
-#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and do not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
+#' Note that the first column of confidence level vector \code{c } should not be specified. If specified, will be ignored , since it is created by \code{  c <-c(rep(C:1))} automatically in the program and it does not refer from user input data even if it is specified explicitly, where \code{C} is the highest number of confidence levels.
 #'So you should check the compatibility of your data and the program's generating new confidence  level vector by
 #'a table which can be displayed by the function \code{\link{viewdata}()}.
 #'
@@ -1124,4 +1124,17 @@ NULL
 
 
 
+# df<-data.frame(ddd$m,ddd$q,ddd$c,ddd$f,ddd$h)
+tabular <- function(df, ...) {
+  stopifnot(is.data.frame(df))
 
+  align <- function(x) if (is.numeric(x)) "r" else "l"
+  col_align <- vapply(df, align, character(1))
+
+  cols <- lapply(df, format, ...)
+  contents <- do.call("paste",
+                      c(cols, list(sep = " \\tab ", collapse = "\\cr\n  ")))
+
+  paste("\\tabular{", paste(col_align, collapse = ""), "}{\n  ",
+        contents, "\n}\n", sep = "")
+}
